<?php
/**
 * Registering meta boxes
 *
 * In this file, I'll show you how to extend the class to add more field type (in this case, the 'taxonomy' type)
 * All the definitions of meta boxes are listed below with comments, please read them carefully.
 * Note that each validation method of the Validation Class MUST return value instead of boolean as before
 *
 * You also should read the changelog to know what has been changed
 *
 * For more information, please visit: http://www.deluxeblogtips.com/2010/04/how-to-create-meta-box-wordpress-post.html
 *
 */

/********************* BEGIN DEFINITION OF META BOXES ***********************/

// prefix of meta keys, optional
// use underscore (_) at the beginning to make keys hidden, for example $prefix = '_rw_';
// you also can make prefix empty to disable it
$prefix = 'classy_';

$classy_meta_boxes = array();


// meta box ===> All Posts
$classy_meta_boxes[] = array(
	'id' => 'all_posts_meta',
	'title' => 'طرح پست',
	'pages' => array('post' , 'services'),
	'context' => 'side',
	'priority' => 'low',
	'fields' => array(
	array(
		'name' => 'پهنای کامل؟',
		'id' => $prefix . 'posts_full_width',
		'type' => 'select', // select box
		'options' => array(
			'No' => 'خیر',
			'Yes' => 'بله'
			),
			'multiple' => false,
			'std' => 'No',
			'desc' => ''
		),
	)
);


// meta box ===> Pages
$classy_meta_boxes[] = array(
	'id' => 'pages_meta',
	'title' => 'تنظیمات صفحه',
	'pages' => array('page' , 'services'),
	'context' => 'normal',
	'priority' => 'high',
	'fields' => array(
		array(
			'name' => 'نقل قول دلخواه',
			'desc' => 'یک نقل قول به این صفحه اضافه کنید. این فقط برای نتایج جستجو کاربرد دارد.',
			'id' => $prefix . 'page_excerpt',
			'type' => 'textarea',
			'std' => ''
		),
	)
);

// meta box ===> Posts
$classy_meta_boxes[] = array(
	'id' => 'single_posts_meta',
	'title' => 'تنظیمات پست',
	'pages' => array('post'),
	'context' => 'side', // where the meta box appear: normal (default), advanced, side; optional
	'priority' => 'low', // order of meta box: high (default), low; optional
	'fields' => array(
	array(
			'name' => 'جزئیات پست',
			'id' => $prefix . 'posts_meta',
			'type' => 'select', // select box
			'options' => array(
				'Show' => 'نمایش',
				'Hide' => 'پنهان'
			),
			'multiple' => false,
			'std' => 'Show',
			'desc' => ''
		),
	array(
			'name' => 'برچسب ها',
			'id' => $prefix . 'posts_tags',
			'type' => 'select', // select box
			'options' => array(
				'Show' => 'نمایش',
				'Hide' => 'پنهان'
			),
			'multiple' => false,
			'std' => 'Show',
			'desc' => ''
	),
		array(
			'name' => 'درباره نویسنده',
			'id' => $prefix . 'posts_author',
			'type' => 'select', // select box
			'options' => array(
				'Enable' => 'فعال',
				'Disable' => 'غیرفعال'
			),
			'multiple' => false,
			'std' => 'Enable',
			'desc' => ''
		),
		array(
			'name' => 'پست های مرتبط',
			'id' => $prefix . 'posts_related',
			'type' => 'select', // select box
			'options' => array(
				'enable' => 'فعال',
				'disable' => 'غیرفعال'
			),
			'multiple' => false,
			'std' => 'enable',
			'desc' => ''
		),
	)
);



// meta box ==> Homepage Highlights
$classy_meta_boxes[] = array(
	'id' => 'hp_highlights_meta', // meta box id, unique per meta box
	'title' => 'تنظیمات هایلایت', // meta box title
	'pages' => array('hp_highlights'),	// post types, accept custom post types as well, default is array('post'); optional
	'context' => 'normal', // where the meta box appear: normal (default), advanced, side; optional
	'priority' => 'high', // order of meta box: high (default), low; optional

	'fields' => array( // list of meta fields
		array(
			'name' => 'آدرس', // field name
			'desc' => 'یک آدرس برای لینک کردن هایلایت ها وارد کنید', // field description, optional
			'id' => $prefix . 'hp_highlights_url', // field id, i.e. the meta key
			'type' => 'text', // text box
			'std' => '', // default value, optional
			'validate_func' => '' // validate function, created below, inside RW_Meta_Box_Validate class
		),
	)
);

// meta box ===> Slides
$classy_meta_boxes[] = array(
	'id' => 'slides_meta',
	'title' => 'تنظیمات اسلایدر',
	'pages' => array('slides'),

	'fields' => array(
		array(
            'name' => 'لینک تصویر اسلاید',
            'desc' => 'آدرسی برای لینک کردن اسلاید ها وارد کنید.',
            'id' => $prefix . 'slides_url',
            'type' => 'text',
            'std' => ''
        ),
		array(
			'name' => 'فاصله دور اسلاید؟',
			'id' => $prefix . 'slides_padding',
			'type' => 'select',
			'options' => array(
				'no' => 'خیر',
				'yes' => 'بله'
			),
			'multiple' => false,
			'desc' => 'گذینه بله را جهت اضافه شدن فاصله دور اسلاید انتخاب کنید.'
		),
	)
);


// meta box ==> Services
$classy_meta_boxes[] = array(
	'id' => 'services_meta',
	'title' => 'تنظیمات خدمات',
	'pages' => array('services'),
	'context' => 'normal',
	'priority' => 'high',

	'fields' => array(
		array(
			'name' => 'توضیحات',
			'desc' => 'یک متن بجای نقل قول برای این آیتم وارد کنید',
			'id' => $prefix . 'services_description',
			'type' => 'textarea',
			'std' => ''
		),
		array(
			'name' => 'آیکون',
			'desc' => 'یک آیکون برای سرویس خود انتخاب کنید. اندازه تصویر باید 25 در 25 باشد.',
			'id' => $prefix . 'services_icon',
			'type' => 'single_image',
			'std' => ''
		),
	)
);


// meta box ==> Staff
$classy_meta_boxes[] = array(
	'id' => 'staff_meta',
	'title' => 'تنظیمات اعضا',
	'pages' => array('staff'),
	'context' => 'معمولی',
	'priority' => 'زیاد',

	'fields' => array(
		array(
            'name' => 'جایگاه',
			'desc' => '',
            'id' => $prefix . 'staff_position',
            'type' => 'text',
            'std' => ''
        ),
		array(
            'name' => 'شرایط',
			'desc' => '',
            'id' => $prefix . 'staff_qualification',
            'type' => 'text',
            'std' => ''
        ),
		array(
            'name' => 'تلفن',
			'desc' => '',
            'id' => $prefix . 'staff_phone',
            'type' => 'text',
            'std' => ''
        ),
		array(
            'name' => 'ایمیل',
			'desc' => '',
            'id' => $prefix . 'staff_email',
            'type' => 'text',
            'std' => ''
        ),
		array(
            'name' => 'وبلاگ',
			'desc' => '',
            'id' => $prefix . 'staff_blog',
            'type' => 'text',
            'std' => ''
        ),
		array(
            'name' => 'آدرس توییتر',
			'desc' => '',
            'id' => $prefix . 'staff_twitter',
            'type' => 'text',
            'std' => ''
        ),
	array(
            'name' => 'صفحه فیسبوک',
			'desc' => '',
            'id' => $prefix . 'staff_facebook',
            'type' => 'text',
            'std' => ''
        ),
	array(
            'name' => 'آدرس گوگل پلاس',
			'desc' => '',
            'id' => $prefix . 'staff_googleplus',
            'type' => 'text',
            'std' => ''
        ),
	array(
            'name' => 'آدرس اسکایپ پلاس',
			'desc' => '',
            'id' => $prefix . 'staff_skype',
            'type' => 'text',
            'std' => ''
        ),
	array(
            'name' => 'آدرس لینکداین',
			'desc' => '',
            'id' => $prefix . 'staff_linkedin',
            'type' => 'text',
            'std' => ''
        ),
	array(
            'name' => 'آدرس پروفایل دریبل',
			'desc' => '',
            'id' => $prefix . 'staff_dribbble',
            'type' => 'text',
            'std' => ''
        ),
	array(
            'name' => 'آدرس فورست',
			'desc' => '',
            'id' => $prefix . 'staff_forrst',
            'type' => 'text',
            'std' => ''
        ),
	array(
            'name' => 'آدرس ویمئو',
			'desc' => '',
            'id' => $prefix . 'staff_vimeo',
            'type' => 'text',
            'std' => ''
        ),
	)
);


// meta box ==> Testimonials
$classy_meta_boxes[] = array(
	'id' => 'testimonials_meta',
	'title' => 'تنظیمات گواهی نامه',
	'pages' => array('testimonials'),
	'context' => 'normal',
	'priority' => 'high',

	'fields' => array(
		array(
            'name' => 'نوشته شده توسط',
            'desc' => 'نام شخص/شرکت که این را نوشته را وارد کنید.',
            'id' => $prefix . 'testimonial_by',
            'type' => 'text',
            'std' => ''
        ),
	)
);

// meta box ==> Portfolio Main
$classy_meta_boxes[] = array(
	'id' => 'portfolio_meta',
	'title' => 'تنظیمات اصلی',
	'pages' => array('portfolio'),
	'context' => 'normal',
	'priority' => 'high',

	'fields' => array(
		array(
            'name' => 'توضیحات',
            'desc' => 'یک توضیح کوتاه برای نمونه کار وارد کنید. فقط در صفحه نمونه کار ها نمایش داده میشود..',
            'id' => $prefix . 'portfolio_description',
            'type' => 'textarea',
            'std' => ''
        ),
		array(
            'name' => 'آدرس',
            'desc' => 'یک آدرس برای درست کردن لینک برای پروژه وارد کنید.',
            'id' => $prefix . 'portfolio_url',
            'type' => 'text',
            'std' => ''
        ),
	array(
            'name' => 'آدرس نوشته',
            'desc' => 'یک نوشته دلخواه برای آدرس نوشته وارد کنید',
            'id' => $prefix . 'portfolio_url_text',
            'type' => 'text',
            'std' => ''
        ),
	)
);

// meta box ==> Portfolio Video
$classy_meta_boxes[] = array(
	'id' => 'portfolio_meta_video',
	'title' => 'تنظیمات ویدئو',
	'pages' => array('portfolio'),
	'context' => 'normal',
	'priority' => 'high',
	'fields' => array(
			array(
				'name' => 'تنظیمات ویدئوی جاسازی شده',
				'desc' => 'کد خود را وارد کنید اگر میخواهید در گالری یک ویدئو به نمایش درآید. حداکثر پهنا 530 پیکسل.',
				'id' => $prefix . 'portfolio_video_embed',
				'type' => 'textarea',
				'std' => ''
			),
		)
);

// meta box ==> Portfolio Extra
$classy_meta_boxes[] = array(
	'id' => 'portfolio_meta_extra',
	'title' => 'مقدار اضافی',
	'pages' => array('portfolio'),
	'context' => 'معمولی',
	'priority' => 'زیاد',
	'fields' => array(
			array(
				'name' => 'مقدار اضافی برای تصویر/ویدئو/اسلایدر. html مجاز است.',
				'id' => $prefix . 'portfolio_below_right',
				'type' => 'textarea',
				'std' => '',
				'desc' => 'شما در اینجا میتوانید یک مقدار اضافی برای تصویر نمونه کار، تصاویر، ویدئو و اسلایدر انتخاب کنید.'
			),
		)
);

// meta box ==> Testimonials
$classy_meta_boxes[] = array(
	'id' => 'pricing_meta',
	'title' => 'تنظیمات جدول قیمیت گذاری',
	'pages' => array('pricing_tables'),
	'context' => 'normal',
	'priority' => 'high',

	'fields' => array(
		array(
			'name' => 'ویژه?',
			'id' => $prefix . 'pricing_tables_featured',
			'type' => 'select',
			'options' => array(
				'no' => 'خیر',
				'yes' => 'بله'
			),
			'multiple' => false,
			'std' => 'no',
			'desc' => 'این یک جدول قیمیت گذاری ویژه است؟'
		),
		array(
				'name' => 'قیمت',
				'desc' => 'یک قیمت برای این جدول انتخاب کنید.',
				'id' => $prefix . 'pricing_tables_price',
				"type" => "text",
				"std" => ""
			),
		array(
				'name' => 'نماد های پولی',
				'desc' => 'نماد پولی خود را وارد کنید. برای مثال: $',
				'id' => $prefix . 'pricing_tables_money_symbol',
				"type" => "text",
				"std" => ""
			),
		array(
				'name' => 'نرخ',
				'desc' => 'یک نرخ برای جدول قیمت گذاری وارد کنید. برای مثال: هر ماه، هر روز',
				'id' => $prefix . 'pricing_tables_rate',
				"type" => "text",
				"std" => ""
			),
		array(
				'name' => 'آدرس ورود/خرید',
				'desc' => 'آدرس ورود یا خرید را وارد کنیدو',
				'id' => $prefix . 'pricing_tables_url',
				"type" => "text",
				"std" => ""
			),
		array(
				'name' => 'نوشته ورود/خرید',
				'desc' => 'نوشته ورود یا خرید را وارد کنید.',
				'id' => $prefix . 'pricing_tables_btn_text',
				"type" => "text",
				"std" => ""
			),
	)
);

foreach ($classy_meta_boxes as $meta_box) {
	new classy_meta_box($meta_box);
}

/********************* END DEFINITION OF META BOXES ***********************/
?>